
from . import reboot
from . import utils
from . import jenkins_key
from . import runtime
from . import homedir
from . import env_home
from . import git
from . import python
from . import python3
from . import projector
from . import sshd
from . import java
from . import vmware_tools
from . import multipath
from . import distribute
from . import virtualenv
from . import fab
from . import jenkins_user
from . import ssh_key
from . import users_homedir
from . import jslave
from . import authenticode
from . import github
from . import visual_studio
from . import path
from . import drivers
from . import computername
from . import timezone
from . import activation
from . import ntpdate
from . import ssl_cert
from . import izbox_kernel
from . import iscsi_kernel
from . import openstack_compute
from . import openstack_devstack
from . import openstack
from . import commvault
from . import winpty
from . import powertools
from . import sysinternals
from . import zsh
from . import home
from infi.vendata.jslave.fabric.utils import platform
from fabric.api import task

CI_DEPLOYMENT_MODULES = [home, runtime, path, homedir, env_home, ssh_key, jenkins_user, git, zsh, python, python3,
                         distribute, virtualenv, fab, projector, jslave, java, authenticode,
                         github, drivers, computername, sshd, ntpdate, ssl_cert, winpty, sysinternals]

DEVELOP_DEPLOYMENT_MODULES = [home, runtime, path, homedir, env_home, git, python, python3,
                       distribute, virtualenv, fab, projector, users_homedir, winpty]

FC_DRIVER_MODULES = [drivers]

def _deploy(deployment_modules, force=False):
    from .utils import user_context
    with user_context():
        if force or not jenkins_key.verify():
            jenkins_key.install()
        for module in deployment_modules:
            if force or not getattr(module, "verify")():
                getattr(module, "install")()
                if not force and not getattr(module, "verify")():
                    msg = "Installation of {module} finish successfully,\n" + \
                            "but it post-installation verification has failed"
                    raise AssertionError(msg.format(module=module.__name__))

@task(default=True)
def deploy():
    _deploy(CI_DEPLOYMENT_MODULES)

@task
def deploy_with_force():
    _deploy(CI_DEPLOYMENT_MODULES, True)

@task
def deploy_development_host():
    _deploy(DEVELOP_DEPLOYMENT_MODULES)

@task
def deploy_fc_drivers():
    _deploy(FC_DRIVER_MODULES)
