from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import put, run, task, settings, abort, hide, puts, get

REPOSITORY = 'http://infinigit.infinidat.com/host/authenticode/blobs/raw/master'

@task
def install():
    from ..utils import determine_platform, user_context
    from ..utils.linux import determine_distribution
    from ...download import download_file_from_repository as download
    from ..homedir import put_file_from_homedir
    with user_context(), settings(warn_only=True):
        if determine_platform() != "windows":
            return
        run ("mkdir .authenticode")
        with download('infinidat_ltd_verisign.pfx', REPOSITORY) as pfx:
            put_file_from_homedir(pfx, ".authenticode/certificate.pfx")
        with download('password', REPOSITORY) as password:
            put_file_from_homedir(password, ".authenticode/certificate-password.txt")

@task
@print_result
def verify():
    from ..utils import determine_platform, user_context, get_tempfile
    from fabric.contrib.files import exists
    from ...download import download_file_from_repository as download
    with user_context():
        if determine_platform() != "windows":
            return True
        for item_tuple  in [('infinidat_ltd_verisign.pfx', ".authenticode/certificate.pfx"),
                            ('password', ".authenticode/certificate-password.txt")]:
            src, dst = item_tuple
            if not exists(dst):
                puts("{} does not exist on the remote host".format(dst))
                return False
            with get_tempfile(dst) as tempfile:
                with open(tempfile) as fd:
                    expected = fd.read()
            with download(src, REPOSITORY) as src:
                with open(src) as fd:
                    actual = fd.read()
            if not actual == expected:
                return False
        return True
