from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task
from ..utils import user_context, untar
from ...download import download_file_from_repository_on_remote_host as download
import os

ARCHIVE_URL_BASE = "http://bootsrv.infinidat.com/clientapps/commvault/"

@task
@print_result
def verify():
    with user_context():
        from fabric.contrib.files import exists
        from ..utils import determine_platform
        if determine_platform() == "windows":
            return exists("/cygdrive/c/program files/commvault/base/snaptest")
        if determine_platform() == "linux":
            return exists("/opt/simpana/Base/SnapTest")
    return False

def _install_windows():
    from ..utils import determine_architecture
    from ..utils.windows import get_homedir_windows_style
    arch_name = "x64" if determine_architecture() == "x86_64" else "x86"    # for name of archive
    arch_name2 = "X64" if determine_architecture() == "x86_64" else "32"    # for name of subdir inside archive
    archive_name = "commvault-windows-{}.tar.gz".format(arch_name)
    answer_name = "answer-file-{}.xml".format(arch_name)
    download("commvault/" + archive_name)
    untar(archive_name)
    run("rm -f CVDownloads/*/Install.xml")
    run("rm {}".format(archive_name))
    run("chmod 777 -R CVDownloads")
    run("easy_install -U infi.run_as")
    download("commvault/" + answer_name)
    installation_base = (get_homedir_windows_style() + "\\CVDownloads\\Win{}\\".format(arch_name2)).replace("\\", "/")
    answer_base = (get_homedir_windows_style() + '\\').replace("\\", "/")
    try:
        run("run_as Administrator Xsignnet1 {0}Setup.exe /silent /play {1}{2}".format(installation_base, answer_base, answer_name))
    except: # requires reboot
        pass


def _fix_etc_hosts():
    run("cat /etc/hosts | grep -v `hostname` > /etc/hosts")

def _install_linux():
    _fix_etc_hosts()
    archive_name = "commvault-linux.tar.gz"
    download("commvault/" + archive_name)
    untar(archive_name)
    with cd("./opt/UnixCustomPackage/pkg"):
        run("./silent_install -params default")
    run("rm {}".format(archive_name))

@task
def install():
    with user_context():
        from ..utils import determine_platform
        if determine_platform() == "windows":
            _install_windows()
        elif determine_platform() == "linux":
            _install_linux()
