from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task
from fabric.contrib.files import exists
from ..utils import user_context, determine_architecture
from ..utils.windows import is_windows_7_or_2008_r2, is_windows_8_or_2012
from ...download import download_file_from_repository_on_remote_host
import os


rename_called = False


def _get_correct_computername():
    import re
    ip_address = run("python -c 'import socket; print socket.gethostbyname(socket.gethostname())'").strip()
    nslookup_output = run("nslookup {}".format(ip_address))
    matchobj = re.search("Name\s*:\s*([^.]+)", nslookup_output)
    if matchobj is None:
        return _get_current_computername()
    return matchobj.group(1)

def _get_current_computername():
    return run("python -c 'import socket; print socket.gethostname()'").strip()


def _change_computername():
    global rename_called
    command = "netdom renamecomputer localhost /NewName:{} /Force".format(_get_correct_computername())
    if is_windows_8_or_2012():
        run("easy_install -U infi.run_as")
        run("run_as Administrator Xsignnet1 {}".format(command))
    else:
        run(command)
    rename_called = True


def _is_netdom_installed():
    try:
        run("netdom")
    except:
        return False
    return True


def _install_netdom():
    arch = "x64" if determine_architecture() == "x86_64" else "x86"
    msu = "Windows6.1-KB958830-{}-RefreshPkg.msu".format(arch) \
          if is_windows_7_or_2008_r2() else "Windows6.2-KB2693643-{}.msu".format(arch)
    download_file_from_repository_on_remote_host(msu)
    run("wusa {} /quiet /norestart".format(msu))
    if is_windows_7_or_2008_r2():
        # we need to install some more stuff
        run("easy_install -U infi.run_as")
        run("run_as Administrator Xsignnet1 pkgmgr /iu:RemoteServerAdministrationTools-Roles-AD-DS-SnapIns\\;RemoteServerAdministrationTools-Roles-AD-DS\\;RemoteServerAdministrationTools-Roles-AD\\;RemoteServerAdministrationTools-Roles\\;RemoteServerAdministrationTools /quiet /norestart")


@task
@print_result
def verify():
    from ..utils import determine_platform
    with user_context():
        return determine_platform() != "windows" or \
               rename_called or \
               _get_current_computername() == _get_correct_computername()


@task
def install():
    with user_context():
        if not _is_netdom_installed():
            _install_netdom()
        _change_computername()
