from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task, puts, env
from ...download import download_file_from_repository_on_remote_host as download
from ..utils import user_context, get_tempfile, reconnect
from infi.vendata.jslave.fabric.utils import get_and_put_file

LOCAL_PYPI_URL = "http://pypi01.infinidat.com"
DOWNLOAD_BASE = LOCAL_PYPI_URL + "/media/dists/"
SETUPTOOLS_SETUP = "ez_setup.py"

def get_latest_version():
    from infi.pypi_manager import DjangoPyPI
    return DjangoPyPI(LOCAL_PYPI_URL).get_latest_version("setuptools")

@task
@print_result
def verify():
    with user_context(), settings(warn_only=True):
       return get_latest_version() in run("easy_install --version")

def _install_from_source():
    base_url, filename = DOWNLOAD_BASE, SETUPTOOLS_SETUP
    download(filename, base_url)
    # On Windows 2008 R2 we have to override the path so powershell won't be found (it get stuck waiting for input)
    run("PATH=~/python/bin python {} --download-base={}".format(filename, DOWNLOAD_BASE))
    run("python -m easy_install --upgrade --script-dir x distribute")
    run("python -m easy_install --upgrade --script-dir x setuptools")
    run("rm -rf x")

def _try_remove_distribute():
    # in Ubuntu we don't want the bad python-distribute package
    with user_context(), settings(warn_only=True):
        run("apt-get remove python-distribute -y")

def _install_linux():
    from ..utils.linux import determine_distribution
    dist, _, _ = determine_distribution()
    if dist in ["ubuntu", ]:
        _try_remove_distribute()
        _install_from_source()
    elif dist in ["redhat", "centos", "suse"]:
        _install_from_source()
    else:
        abort("unknown operating system")

def _install_windows():
    _install_from_source()

def _install_solaris():
    _install_from_source()

def _install_darwin():
    from fabric.api import sudo
    _install_from_source()
    sudo("ln -s -f ~/python/bin/easy_install /usr/bin/easy_install")
    sudo("ln -s -f ~/python/bin/easy_install-2.7 /usr/bin/easy_install-2.7")

@task
def install():
    with user_context():
        from ..utils import determine_platform
        if determine_platform() == "linux":
            _install_linux()
        elif determine_platform() in ["windows", ]:
            _install_windows()
        elif determine_platform() == "darwin":
            _install_darwin()
        elif determine_platform() == "sunos":
            _install_solaris()
        else:
            abort("unknown operating system")
