from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task
from ..utils import user_context
import os

def _is_emulex_driver_installed():
    drivers = run("driverquery /v").splitlines()
    elx_line = [line for line in drivers if 'elxfc ' in line]
    return len(elx_line) == 1 and "Running" in elx_line[0]

def _has_emulex_device():
    # we get the hardware ids of all pci devices from the registry and check there
    # All of our emulex devices have the same hardware ID. Vendor ID = 10DF, Device ID = F100, Class ID = C04
    return "VEN_10DF&DEV_F100" in run(r"reg query 'HKLM\SYSTEM\CurrentControlSet\Enum\PCI'")

def _run_script_remotely(script_path):
    """ copy a local python script and run it remotely """
    basename = os.path.basename(script_path)
    put(script_path, "~/{}".format(basename))
    try:
        run("python {}".format(basename))
    finally:
        run("rm ~/{}".format(basename))

@task
@print_result
def verify():
    from ..utils import determine_platform
    with user_context():
        return determine_platform() != "windows" or not _has_emulex_device() or _is_emulex_driver_installed()

@task
def install():
    with user_context():
        local_script_path = os.path.join(os.path.dirname(__file__), "install_emulex_driver.py")
        _run_script_remotely(local_script_path)
