from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task, puts, env
from ...download import download_file_from_repository as download
from ..utils import user_context, get_tempfile, reconnect
from infi.vendata.jslave.fabric.utils import get_and_put_file

@task
@print_result
def verify():
    with user_context(), settings(warn_only=True):
        from infi.pypi_manager import DjangoPyPI
        from ..utils import determine_platform
        # case-sensitivity issues with djangopypi require this hack
        latest_version = DjangoPyPI("http://pypi01.infinidat.com").get_latest_version("Fabric")
        result = run("fab --version")
        return latest_version in result or '1.8.3' in result or '1.8.2' in result

def _install_from_easyinstall():
    run("easy_install -U ssh==1.7.8")
    run("easy_install -U Fabric")

def _install_linux():
    from ..utils.linux import determine_distribution
    dist, _, _ = determine_distribution()
    _install_from_easyinstall()

def _install_solaris():
    _install_from_easyinstall()

def _install_windows():
    run("easy_install -U pywin32")
    _install_from_easyinstall()

def _install_darwin():
    from ..utils import link
    _install_from_easyinstall()
    link("~/python/bin/fab", "/usr/local/bin/fab")

@task
def install():
    with user_context():
        from ..utils import determine_platform
        if determine_platform() == "linux":
            _install_linux()
        elif determine_platform() in ["windows", ]:
            _install_windows()
        elif determine_platform() == "darwin":
            _install_darwin()
        elif determine_platform() == "sunos":
            _install_solaris()
        else:
            abort("unknown operating system")
