from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import task, put, puts, run
from fabric.state import env
from ..utils import user_context, reconnect
from ..utils.windows import get_windows_profile, get_windows_default_profile, get_systemroot
from ..utils.windows import is_administrator_account_exists
from fabric.contrib.files import exists as remote_exists

resource_manager = __name__

def _get_windows_profilebasedir():
    return get_windows_profile() if is_administrator_account_exists() else get_windows_default_profile()

def put_file_from_homedir(local_filename, remote_filename=None):
    from os.path import join, exists, dirname
    from ..utils import determine_platform
    from pkg_resources import resource_filename
    src = resource_filename(__name__, local_filename)
    dst = remote_filename if remote_filename is not None else local_filename
    if not exists(src):
        if exists(local_filename):
            src = local_filename
        else:
            raise RuntimeError("file not found: %s", src)
    remote_dirname = dirname(dst)
    if remote_dirname and not remote_exists(remote_dirname):
        run("""mkdir -p "{}" """.format(remote_dirname))
    put(src, dst)
    if determine_platform() == "windows":
        dst = "/".join([_get_windows_profilebasedir(),
                        remote_filename if remote_filename is not None else local_filename])
        remote_dirname = dirname(dst)
        if remote_dirname and not remote_exists(remote_dirname):
            run("""mkdir -p "{}" """.format(remote_dirname))
        put(src, dst)

def _put_cpau():
    from tempfile import mkstemp
    from urllib2 import urlopen
    from os import write, close
    fd, name = mkstemp()
    write(fd, urlopen("http://bootsrv/clientapps/cpau.exe").read())
    close(fd)
    put(name, "/".join([get_systemroot(), "cpau.exe"]))

@task
def buildout():
    from fabric.contrib.files import exists
    from ..utils import determine_platform
    with user_context():
        put_file_from_homedir(".buildout/default.cfg", ".buildout/default.cfg")

@task
def pip():
    from fabric.contrib.files import exists
    from ..utils import determine_platform
    with user_context():
        dirname = "{}pip".format('' if determine_platform()=="windows" else '.')
        filename = "pip.{}".format('ini' if determine_platform()=="windows" else 'conf')
        put_file_from_homedir(".pip/pip.conf", "{}/{}".format(dirname, filename))

@task
def ssh_config():
    from fabric.contrib.files import exists
    from ..utils import determine_platform
    with user_context():
        put_file_from_homedir(".ssh/config", ".ssh/config")

@task
def infinilab_certificate():
    from fabric.contrib.files import exists
    from ..utils import determine_platform
    with user_context():
        put_file_from_homedir(".infinidat/infinilab.crt", ".infinidat/infinilab.crt")

@task
def infinilab_token():
    from fabric.contrib.files import exists
    from ..utils import determine_platform
    with user_context():
        put_file_from_homedir(".infinidat/infinilab.tkn", ".infinidat/infinilab.tkn")

@task
def pydistutils():
    from ..utils import determine_platform
    with user_context():
        platform = determine_platform()
        dst = "pydistutils.cfg" if platform == "windows" else None
        put_file_from_homedir(".pydistutils.cfg", dst)

@task
def gitconfig():
    with user_context():
        put_file_from_homedir(".gitconfig")

@task
def pylintrc():
    with user_context():
        put_file_from_homedir(".pylintrc")

@task
def pypirc():
    with user_context():
        put_file_from_homedir(".pypirc")

def create_jenkins_dir_in_windows_profile():
    from fabric.contrib.files import exists
    dst = '/'.join([get_windows_profile(), "jenkins"])
    if not exists(dst):
        run("""mkdir -p "{}" """.format(dst))

def create_administrator_profile_by_running_something():
    with user_context():
        _put_cpau()
        cmdline = "{}/cpau.exe -u {} -p {} -ex msg.exe -profile"
        run(cmdline.format(get_systemroot(), env['user'], env['password']))

@task
def install():
    from ..utils import determine_platform
    with user_context():
        buildout()
        pydistutils()
        pylintrc()
        pypirc()
        pip()
        ssh_config()
        gitconfig()
        infinilab_certificate()
        infinilab_token()
        if determine_platform() == "windows" and not is_administrator_account_exists():
            create_administrator_profile_by_running_something()

@task
@print_result
def verify():
    from ..utils import determine_platform
    from fabric.contrib.files import exists
    infinilab_token()
    for filename in [".pylintrc", ".pypirc", ".buildout",
                     "{}pydistutils.cfg".format('' if determine_platform() == "windows" else '.'),
                     "{}pip/pip.{}".format('' if determine_platform() == "windows" else '.',
                                           "ini" if determine_platform() == "windows" else "conf"),
                     ".ssh/config"]:
        if not exists(filename):
            puts("{} does not exist on the remote host".format(filename))
            return False
    return True
