from fabric.api import cd, put, run, abort, settings, task, puts
from infi.vendata.jslave.fabric.utils import print_result, user_context
from infi.vendata.jslave.fabric.utils.linux import determine_distribution


REPO_NAME = "iscsi-repo.lab.il.infinidat.com"
KERNEL_VERSIONS = {
    "redhat": {"7": "3.10.0-123.6.3.el7.iscsigw"},
    "centos": {"6": "2.6.32-431.17.1.el6.iscsigw"}
}


def get_version():
    with user_context():
        from ..utils import determine_platform
        from ..utils.linux import determine_distribution
        if determine_platform() != "linux":
            return False
        dist, version, codename = determine_distribution()
        return KERNEL_VERSIONS.get(dist, dict()).get(version[0])


@task
@print_result
def verify():
    with user_context():
        version = get_version()
        if version is None:
            return True
        return version in run("uname -r")


@task
def install():
    with user_context():
        version = get_version()
        if version is None:
            return False
        run("curl http://{}/setup | sudo sh -".format(REPO_NAME))
        run("yum install -y --disablerepo=* --enablerepo={0} kernel-{1} kernel-devel-{1} kernel-headers-{1}".format(REPO_NAME, version))
        # if this is executed after a previously installing a compatible package, this will happend:
        # Package matching kernel-headers-2.6.32-358.14.1.el6.x86_64 already installed. Checking for update
        # so we need the following workaround:
        run("yum downgrade -y --disablerepo=* --enablerepo={0} kernel-{1} kernel-devel-{1} kernel-headers-{1}".format(REPO_NAME, version))
        # this also happens with we pass to elabit --addtional-tasks, as they are executed as the end
        run("new-kernel-pkg -v --mkinitrd --dracut --depmod --install {0}.x86_64 --make-default".format(version))
