from fabric.api import cd, put, run, abort, settings, task, puts
from infi.vendata.jslave.fabric.utils import print_result, user_context
from infi.vendata.jslave.fabric.utils import get_and_put_file


REPO_NAME = "izbox-repo.lab.il.infinidat.com"
KERNEL_VERSION = "2.6.32-358.14.1.el6"


def check_host():
    with user_context():
        from ..utils import determine_platform
        from ..utils.linux import determine_distribution
        if determine_platform() != "linux":
            return False
        dist, version, codename = determine_distribution()
        if dist != "centos" or version != "6.4":
            return False
        return True

@task
@print_result
def verify():
    with user_context():
        if not check_host():
            return True
        return REPO_NAME in run("yum info kernel")

def replace_kernel_version_in_file(remote_filepath):
    old_version = "2.6.32-358.el6.x86_64"
    new_version = "2.6.32-358.14.1.el6.x86_64"
    with get_and_put_file(remote_filepath) as local_path:
        with open(local_path, 'rb') as fd:
            content = fd.read()
        with open(local_path, 'wb') as fd:
            fd.write(content.replace(old_version, new_version))

def update_grub_conf():
    replace_kernel_version_in_file("/etc/grub.conf")
    replace_kernel_version_in_file("/boot/grub/grub.conf")

@task
def install():
    with user_context():
        if not check_host():
            return
        run("curl http://{}/setup | sudo sh -".format(REPO_NAME))
        run("yum install -y --disablerepo=* --enablerepo={0} kernel-{1} kernel-devel-{1} kernel-headers-{1}".format(REPO_NAME, KERNEL_VERSION))
        # if this is executed after a previously installing a compatible package, this will happend:
        # Package matching kernel-headers-2.6.32-358.14.1.el6.x86_64 already installed. Checking for update
        # so we need the following workaround:
        run("yum downgrade -y --disablerepo=* --enablerepo={0} kernel-{1} kernel-devel-{1} kernel-headers-{1}".format(REPO_NAME, KERNEL_VERSION))
        # this also happens with we pass to elabit --addtional-tasks, as they are executed as the end
        update_grub_conf()
