
from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task, puts
from ...download import download_file_from_repository_on_remote_host as download
from ..utils import user_context, reconnect, untar

def _get_java_archive_name():
    from ..utils import determine_architecture, determine_platform
    arch_name = "x64" if determine_architecture() == "x86_64" else "i586"
    if determine_platform() == "windows":
        return "jre-6u25-windows-{}.tar.gz".format(arch_name)
    elif determine_platform() == "linux":
        return "jre-6u26-linux-{}-rpm.bin".format(arch_name)

def _get_java_bin_dir_windows():
    from ..utils import determine_architecture
    from ..utils.windows import get_program_files_windows_style
    if determine_architecture() == "x86_64":
        return "\\".join([get_program_files_windows_style(), "Java", "jre6", "bin"])
    else:
        return "\\".join([get_program_files_windows_style(), "Java", "jre1.6.0_25", "bin"])

def _get_java_bin_dir_posix():
    from ..utils import determine_platform, determine_architecture
    from ..utils.windows import get_program_files_posix_style
    if determine_platform() == "windows":
        if determine_architecture() == "x86_64":
            return "/".join([get_program_files_posix_style(), "Java", "jre6", "bin"])
        else:
            return "/".join([get_program_files_posix_style(), "Java", "jre1.6.0_25", "bin"])
    else:
        return "/usr/bin"

def _get_java_binary():
    from ..utils import determine_platform
    return "/".join([_get_java_bin_dir_posix(), "java.exe" if determine_platform() == "windows" else "java"])

def _install_from_download_repository():
    from ..utils import determine_architecture, determine_platform
    from ..utils.windows import append_to_systemwide_path
    from ..utils.unix import append_to_user_ssh_path_variable
    archive_name = _get_java_archive_name()
    download("java/" + archive_name)
    if determine_platform() == "windows":
        untar(archive_name)
        with cd("java"):
            run("/cygdrive/c/windows/system32/msiexec /i setup.msi /qn")
        append_to_systemwide_path(_get_java_bin_dir_windows())
        append_to_user_ssh_path_variable(_get_java_bin_dir_posix())
    elif determine_platform() == "linux":
        run("mv -f /usr/bin/{,_}java || true") # move aside an older installation of java if exists
        run("chmod u+x {}".format(archive_name))
        run("./{}".format(archive_name))

def _install_from_apt():
    from ..utils.linux import apt_get
    apt_get("default-jre")

@task
def install():
    with user_context():
        from ..utils import determine_platform, determine_architecture
        from ..utils.linux import determine_distribution
        from ..utils.windows import get_homedir_windows_style, append_to_systemwide_path
        if determine_platform() == "linux":
            dist, _, _ = determine_distribution()
            if dist in ["ubuntu", ]:
                _install_from_apt()
            elif dist in ["redhat", "centos", "suse"]:
                _install_from_download_repository()
            else:
                abort("unsupported platform")
        elif determine_platform() == "windows":
            _install_from_download_repository()
        else:
            abort("unsupported platform")

@task
@print_result
def verify():
    from fabric.contrib.files import exists
    with user_context(), settings(warn_only=True):
        java = _get_java_binary()
        if not exists(java.replace("\ ", ' ')):
            puts("java binary {} does not exist".format(repr(java)))
            return False
        version = run("{} -version".format(java))
        return "1.6" in version or "1.7" in version
