from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import settings, run, task, puts
from ..utils import user_context, get_tempfile, determine_platform, get_and_put_file


def _get_public_key():
    from ... import JENKINS_KEY_PAIR
    with open(JENKINS_KEY_PAIR[1]) as fd:
        return fd.read().strip()


@task
@print_result
def verify():
    from fabric.contrib.files import exists
    with user_context(), settings(warn_only=True):
        path = ".ssh/authorized_keys"
        if not exists(path):
            puts("there is no authorized_keys file\n")
            return False
        with get_tempfile(path) as local_path:
            with open(local_path) as fd:
                content = fd.read().splitlines()
            result = _get_public_key() in content
    puts("jenkins public key is {}\n".format("installed" if result else "not installed"))
    return result


@task
def install():
    from fabric.contrib.files import exists
    with user_context(), settings(warn_only=True):
        remote_path = ".ssh/authorized_keys"
        if not exists(remote_path):
            if not exists(".ssh"):
                run("mkdir .ssh")
            run("touch {}".format(remote_path))
        with get_and_put_file(remote_path) as local_path:
            with open(local_path, 'a') as fd:
                fd.write(_get_public_key() + "\n")
