from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import cd, put, run, abort, settings, task, puts, env
from ...download import download_file_from_repository as download
from ..utils import user_context, get_tempfile, reconnect
from infi.vendata.jslave.fabric.utils import get_and_put_file

@task
@print_result
def verify():
    with user_context(), settings(warn_only=True):
        from ..utils import determine_platform
        if determine_platform() == "linux":
            return _verify_linux()
        if determine_platform() == "sunos":
            return True
        elif determine_platform() in ["windows", ]:
            return True
        else:
            abort("unknown operating system")

def _create_posix_user():
    run("useradd --shell /bin/bash --skel /root --create-home --password jenkins jenkins")

def _add_to_sudoers():
    from ..utils import get_and_put_file
    with get_and_put_file("/etc/sudoers") as sudoers_path:
        with open(sudoers_path, 'a') as sudoers_fd:
            sudoers_fd.write("\njenkins ALL = NOPASSWD: ALL\n")

def _install_unix():
    _create_posix_user()
    _add_to_sudoers()


def _verify_linux():
    from ..utils.linux import determine_distribution
    dist, _, _ = determine_distribution()
    if dist in ["ubuntu", ]:
        return "uid" in run("id jenkins")
    else:
        return True

@task
def install():
    with user_context():
        from ..utils import determine_platform
        if determine_platform() == "linux" or determine_platform() == "sunos":
            _install_unix()
        elif determine_platform() in ["windows", ]:
            pass
        else:
            abort("unknown operating system")

