from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import put, run, task, settings, abort, hide
from ...download import download_file_from_repository as download
from ..utils import reconnect

def _install_mpio_feature():
    from ..utils import determine_architecture
    # There too many methods of installing this on Windows.
    # TBD
    raise NotImplementedError

def _install_from_apt():
    from ..utils.linux import apt_get
    apt_get("multipath-tools")

def _install_from_yum():
    from fabric.contrib.files import exists
    run("yum install -y device-mapper-multipath")
    run("chkconfig --levels 2345 multipathd on")
    with settings(warn_only=True):
        run("insmod /lib/modules/*/kernel/drivers/md/*multipath*")
        run("/etc/init.d/multipathd start")
    if not exists("/etc/multipath.conf"):
        run("cp /usr/share/doc/device-mapper-multipath-0*/multipath.conf.defaults /etc/multipath.conf")

def _install_from_zypper():
    run("zypper --non-interactive --no-gpg-checks install --auto-agree-with-licenses multipath-tools")

@task
def install():
    from ..utils import determine_platform, user_context
    from ..utils.linux import determine_distribution
    with user_context():
        if determine_platform() == "windows":
            _install_mpio_feature()
        if determine_platform() == "linux":
            dist, _ , _ = determine_distribution()
            if dist in ["redhat", "centos"]:
                _install_from_yum()
            elif dist in ["ubuntu", ]:
                _install_from_apt()
            elif dist in ["suse"]:
                _install_from_zypper()
            else:
                abort("unsupported platform")

@task
@print_result
def verify():
    from ..utils import determine_platform, user_context
    from fabric.contrib.files import exists
    with user_context():
        if determine_platform() == "windows":
            raise NotImplementedError
        elif determine_platform() == "linux":
            return exists("/sbin/multipath")
        else:
            abort("unsupported platform")
