from fabric.api import cd, put, run, abort, settings, task, puts
from infi.vendata.jslave.fabric.utils import print_result, user_context

@task
@print_result
def verify():
    with user_context():
        with settings(warn_only=True):
            from ..utils import determine_platform
            from ..utils.linux import determine_distribution
            if determine_platform() != "linux":
                return True
            dist, version, codename = determine_distribution()
            if dist in ["redhat", "centos"]:
                package = "ntp" if version[0] in ("4", "5") else "ntpdate"
                return "installed" in run("yum info {}".format(package))
            elif dist in ["ubuntu"]:
                return "Inst" in run("dpkg -l ntpdate")
            elif dist in ["suse"]:
                return not "not installed" in run("rpm -q yast2-ntp-client")
            else:
                raise abort("unsupported platform")


@task
def install():
    with user_context():
        from ..utils import determine_platform
        from ..utils.linux import determine_distribution
        if determine_platform() != "linux":
            return
        dist, version, codename = determine_distribution()
        if dist in ["redhat", "centos"]:
            package = "ntp" if version[0] in ("4", "5") else "ntpdate"
            run("yum install -y {}".format(package))
        elif dist in ["ubuntu"]:
            run("apt-get install -y ntpdate")
        elif dist in ["suse"]:
            run("zypper --non-interactive --no-gpg-checks install --auto-agree-with-licenses yast2-ntp-client")
        else:
            raise abort("unsupported platform")
