from ..utils.linux import determine_distribution
from ..utils import user_context
from fabric.api import run, task, abort


def install_packstack():
    run("yum update -y")
    run("yum install -y http://rdo.fedorapeople.org/rdo-release.rpm")
    run("yum install -y openstack-packstack")


def run_packstack():
    try:
        run("packstack --allinone --debug --keystone-admin-passwd=admin --keystone-demo-passwd=demo")
    except:
        run("cat /var/tmp/packstack/*/openstack-setup.log")
        raise

def quickstart():
    # http://openstack.redhat.com/Quickstart
    install_packstack()
    run_packstack()


def setup_redhat_subscription():
    run("subscription-manager register --username=partners.infi --password='$6Eye6KufX' --force")
    run("subscription-manager attach --auto")


def configure_redhat_yum_repositories():
    run("yum-config-manager --enable rhel-7-server-optional-rpms") # ruby-selinux
    run("yum-config-manager --enable rhel-7-server-extras-rpms") # python-itsdangerous


@task
def install():
    distro, distro_version, _ = determine_distribution()
    if distro not in ('redhat', 'centos'):
        abort("distro {} not supported".format(distro))
    if distro_version[0] not in ('6', '7'):
        abort("distro version {} not supported".format(distro_version))

    with user_context():
        if distro in ('redhat', ) and distro_version[0] in ('7', ):
            setup_redhat_subscription()
            install_packstack()
            configure_redhat_yum_repositories()
            run_packstack()
        else:
            quickstart()

