from ..utils import user_context, is_windows, is_solaris, reconnect_after
from fabric.api import task
from ..utils.windows import get_systemwide_path_variable, append_to_systemwide_path
from ..utils.unix import append_to_user_ssh_path_variable, get_user_ssh_path_variable, append_to_bashrc
from infi.vendata.jslave.fabric.utils import print_result

CYGWIN_BIN_PATH = r"C:\Cygwin\bin"
CYGWIN_BIN_PATH_IN_CYGWIN = "/cygdrive/c/Cygwin/bin"

CSW_BIN_PATH = "/opt/csw/bin"
CSW_INCLUDE_PATH = "/opt/csw/include"
CCS_BIN_PATH = "/usr/ccs/bin"
CSW_GNU_PATH = "/opt/csw/gnu"

def add_to_windows_path(windows_path, cygwin_path):
    append_to_user_ssh_path_variable(cygwin_path)
    append_to_systemwide_path(windows_path)

def add_to_solaris_path(path):
    append_to_user_ssh_path_variable(path)

@task
@print_result
def verify():
    with user_context():
        if is_windows():
            return CYGWIN_BIN_PATH_IN_CYGWIN in get_user_ssh_path_variable().split(":") and \
                   CYGWIN_BIN_PATH in get_systemwide_path_variable().split(";")
        elif is_solaris():
            path = get_user_ssh_path_variable().split(":")
            return CCS_BIN_PATH in path and CSW_BIN_PATH in path
        return True

@task
@reconnect_after
def install():
    with user_context():
        if is_windows():
            add_to_windows_path(CYGWIN_BIN_PATH, CYGWIN_BIN_PATH_IN_CYGWIN)
        elif is_solaris():
            # TODO if export is doing a problem fix it in this layer
            append_to_bashrc('alias tail=gtail')
            append_to_bashrc('alias ls="gls --color=tty"')
            append_to_bashrc('alias date=gdate')
            append_to_bashrc('export C_INCLUDE_PATH={}'.format(CSW_INCLUDE_PATH))
            append_to_bashrc('export TERM=xterm')
            append_to_user_ssh_path_variable(CSW_BIN_PATH)
            append_to_user_ssh_path_variable(CCS_BIN_PATH)
            append_to_user_ssh_path_variable(CSW_GNU_PATH)
