from infi.vendata.jslave.fabric.utils import print_result
from fabric.api import run, settings, task
from ..utils import user_context
from ..utils.linux import is_ppa_capable, add_ppa_repository, determine_distribution, apt_get

@task
@print_result
def verify():
    from fabric.contrib.files import exists
    from pkg_resources import parse_version
    with user_context(), settings(warn_only=True):
        if not is_ppa_capable():
            return True
        dist, version, release = determine_distribution()
        if parse_version(version) < parse_version("12.04"):  # the ppa we use does not have python3.3 for older ones
            return True
        return exists("/usr/bin/python3.3")


def _install_ubuntu():
    add_ppa_repository("fkrull/deadsnakes")
    apt_get("python3.3")


@task
def install():
    with settings(warn_only=True), user_context():
        if is_ppa_capable():
            _install_ubuntu()
