
from fabric.api import settings, run, task, puts
from ..utils import user_context, get_tempfile, determine_platform, get_and_put_file
from infi.vendata.jslave.fabric.utils import print_result

@task
@print_result
def verify():
    from fabric.contrib.files import exists
    with user_context(), settings(warn_only=True):
        for path in [".ssh/id_rsa", ".ssh/id_rsa.pub"]:
            if not exists(path):
                puts("there is no ssh key: {}\n".format(path))
                return False
            with get_and_put_file(path) as id_rsa:
                with open(id_rsa) as fd:
                    if not fd.read().strip().strip("\x00"):
                        puts("the ssh key file is empty: {}\n".format(path))
                        return False
    return True

def delete_existing_ssh_key():
    run("rm -f .ssh/id_rsa .ssh/id_rsa.pub")

def generate_new_ssh_key():
    run("mkdir -p .ssh")
    run("""ssh-keygen -t rsa -f .ssh/id_rsa -P "" """)

def put_ssh_key_in_authorized_keys():
    with get_and_put_file(".ssh/authorized_keys") as authorized_keys:
        with get_and_put_file(".ssh/id_rsa.pub") as public_key:
            with open(public_key) as fd:
                content = fd.read()
            with open(authorized_keys, 'a') as fd:
                fd.write("\n{}\n".format(content))

def fix_permissions():
    run("chmod 500 .ssh")
    run("chmod 400 .ssh/authorized_keys")

@task
def install():
    from fabric.contrib.files import exists
    with user_context():
        delete_existing_ssh_key()
        generate_new_ssh_key()
        put_ssh_key_in_authorized_keys()
        fix_permissions()

