
from infi.pyutils.contexts import contextmanager
from fabric.api import run, task, settings
from ..utils import user_context
from infi.vendata.jslave.fabric.utils import print_result

@task
def restart():
    from ..utils import determine_platform
    with user_context():
        if determine_platform() == "windows":
            run("sc stop sshd; sc start sshd")
        elif determine_platform() == "linux":
            run("/etc/init.d/*ssh* restart")


@contextmanager
def sshd_config(mode):
    from ..utils import determine_platform, get_and_put_file, get_tempfile
    sshd_config = "/etc/sshd_config" if determine_platform() == "windows" else "/etc/ssh/sshd_config"
    sshd_context = get_tempfile if mode == 'r' else get_and_put_file
    with user_context():
        with sshd_context(sshd_config) as local_sshd_config:
            with open(local_sshd_config, mode) as fd:
                yield fd

@task
def install():
    with sshd_config('a') as fd:
        fd.write("\n".join(['', 'ClientAliveCountMax 99', 'ClientAliveInterval 60', 'TCPKeepAlive no', '']))

@task
@print_result
def verify():
    with sshd_config('r') as fd:
        content = fd.read()
        return 'TCPKeepAlive no' in content
