
from fabric.api import settings
from unittest import SkipTest
from infi import unittest
from infi.pyutils.decorators import wraps
from .. import deploy, deploy_development_host

from logging import getLogger
logger = getLogger(__name__)

ALL_JSLAVE_NUMBERS = [1, 2, 3, 5, 6, 7]
ALL_TEST_HOSTS = ["jslave{:02}".format(num) for num in ALL_JSLAVE_NUMBERS]


def wait_for_ssh(names, timeout_seconds=600, sleep_seconds=60):
    from waiting import wait
    def predicate():
        from socket import create_connection
        for name in names:
            try:
                create_connection((name, 22))
            except Exception:
                return False
        return True
    wait(predicate, timeout_seconds=timeout_seconds, sleep_seconds=sleep_seconds)


def restore_hosts_fom_snapshot():
    from infi.pyvmomi_wrapper import Client
    from testconfig import config
    if 'server' not in config:
        raise SkipTest()
    client = Client(config['server'], config['username'], config['password'])
    vms = [client.get_virtual_machine(name) for name in ALL_TEST_HOSTS]
    tasks = [vm.PowerOffVM_Task() for vm in vms if vm.runtime.powerState == "poweredOn"]
    client.wait_for_tasks(tasks)
    tasks = [vm.RevertToCurrentSnapshot_Task() for vm in vms]
    client.wait_for_tasks(tasks)
    tasks = [vm.PowerOnVM_Task() for vm in vms]
    client.wait_for_tasks(tasks)
    wait_for_ssh(ALL_TEST_HOSTS)


class DeployTestCase(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        super(DeployTestCase, cls).setUpClass()
        restore_hosts_fom_snapshot()

    @unittest.parameters.iterate("num", ALL_JSLAVE_NUMBERS)
    def test_deploy_on_jslave(self, num):
        try:
            with settings(host_string="jslave{:02}.lab.il.infinidat.com".format(num)):
                if num == 7:
                    deploy_development_host()
                else:
                    deploy()
        except SystemExit:
            logger.exception("caught SystemExit")
            self.fail("Caught SystemExit")
