from fabric.api import cd, put, run, abort, settings, task, puts
from ..utils import user_context, determine_platform
from infi.vendata.jslave.fabric.utils import print_result


def install_linux():
    import os
    localtime_path = os.path.join(os.path.dirname(__file__), "localtime")
    put(localtime_path, "/etc/localtime")


@task
@print_result
def verify():
    import datetime, time
    from email.utils import parsedate_tz
    with user_context():
        if determine_platform() not in ["linux", "windows"]:
            return True
        output = run("date --rfc-2822")
    if output.endswith("+0000"):
        # UTC and not IST/IDT (JST/JDT) (Israel/Jerusalem Standard/Daylight time)
        return False
    parsed_output = parsedate_tz(output)
    host_time = datetime.datetime.fromtimestamp(time.mktime(parsed_output[:-1]))
    cur_time = datetime.datetime.now()
    time_diff = max([host_time, cur_time]) - min([host_time, cur_time])
    puts("Time: {} Diff in seconds: {}".format(host_time, time_diff.seconds))
    return time_diff.seconds < 30 * 60


@task
def install():
    from .windows import install_windows
    with user_context():
        if determine_platform() in ["linux", ]:
            install_linux()
        elif determine_platform() in ["windows", ]:
            install_windows()
        else:
            abort("unsupported platform")