from fabric.api import settings, run, task, puts
from ..utils import user_context, determine_platform
from infi.vendata.jslave.fabric.utils import print_result

FILES_TO_COPY = ['.buildout/default.cfg', '.pydistutils.cfg', '.pip/pip.conf']
FILES_TO_COPY_WIN = ['.buildout/default.cfg', 'pydistutils.cfg', 'pip/pip.ini']

@task
@print_result
def verify():
    from fabric.contrib.files import exists
    with user_context(), settings(warn_only=True):
        users = run("ls -1 /home").stdout.strip()
        users = users.split("\n") if len(users) > 0 else []
        files_to_copy = FILES_TO_COPY_WIN if determine_platform() == "windows" else FILES_TO_COPY
        for f in files_to_copy:
            for user in users:
                sudo_prefix = "" if determine_platform() == "windows" else "sudo -u {} ".format(user)
                if run("{}test -f /home/{}/{}".format(sudo_prefix, user, f)).return_code != 0:
                    return False
    return True

@task
def install():
    from fabric.contrib.files import exists
    from os import listdir
    from os.path import basename, dirname
    with user_context(), settings(warn_only=True):
        users = run("ls -1 /home").stdout.strip()
        users = users.split("\n") if len(users) > 0 else []
        files_to_copy = FILES_TO_COPY_WIN if determine_platform() == "windows" else FILES_TO_COPY
        for f in files_to_copy:
            run("cp ~/{} /tmp/".format(f))
            for user in users:
                sudo_prefix = "" if determine_platform() == "windows" else "sudo -u {} ".format(user)
                if dirname(f):
                    run("{}mkdir -p /home/{}/{}".format(sudo_prefix, user, dirname(f)))
                run("{}cp /tmp/{} /home/{}/{}".format(sudo_prefix, basename(f), user, f))
