from fabric.api import run, abort, settings, task
from infi.vendata.jslave.fabric.utils import user_context, determine_platform, link

class EasyInstall(object):
    def __init__(self, package_name, script_name=None):
        super(EasyInstall, self).__init__()
        self.package_name = package_name
        self.script_name = script_name or package_name

    def get_latest_version(self):
        from infi.pypi_manager import DjangoPyPI
        return DjangoPyPI("pypi01.infinidat.com").get_latest_version(self.package_name)

    def verify(self):
        with user_context(), settings(warn_only=True):
            return self.get_latest_version() in run("{} --version".format(self.script_name))

    def install_from_easy_install(self):
        run("easy_install -U {}".format(self.package_name))

    def install_darwin(self):
        from .. import link
        self.install_from_easyinstall()
        link("~/python/bin/virtualenv", "/usr/local/bin/virtualenv")

    def install(self):
        with user_context():
            from .. import determine_platform
            if determine_platform() in ["windows", "linux", "sunos"]:
                try:
                    self.install_from_easy_install()
                except:
                    pass  # error: C:\Cygwin\home\Administrator\python\Scripts\jfab.exe: Access is denied
                if determine_platform() == "windows":
                    run("chmod 777 python/Scripts/*")
            elif determine_platform() == "darwin":
                self.install_darwin()
            else:
                abort("unknown operating system")

