
from fabric.api import run, task, env, puts
from infi.pyutils.lazy import cached_function
from .. import user_context

@cached_function
def _determine_distribution_for_host(host_string):
    output = run("""python -c 'import platform; dist, version, release = platform.dist(); print ",".join([dist.lower(), version, release])'""")
    result = output.stdout.strip('\n').split(',')
    if not result:
        return ""
    # workaround platform bug - python recognizes redhat as centos when using "dist". See HOSTDEV-1574
    if result[0] == "centos":
        output = run("""python -c 'import platform; dist = platform.linux_distribution(); print dist[0]'""")
        result[0] = "redhat" if output.startswith("Red") else "centos"
    puts("distribution is {}".format(','.join(result)))
    return result

@task
def determine_distribution():
    """returns: dist, version, release. for example: redhat,5.6,Tikanga, "ubuntu,11.04,natty"""
    with user_context():
        return _determine_distribution_for_host(env.host_string)

def apt_get(package):
    run("rm -f /etc/apt/apt.conf; apt-get install -y {} --fix-missing --force-yes".format(package))

def is_ppa_capable():
    from .. import determine_platform
    if determine_platform() != "linux":
        return False
    dist, version, release = determine_distribution()
    if dist not in ["ubuntu", ]:
        return False
    return True

def add_ppa_repository(repository_name):
    from fabric.contrib.files import exists
    if not exists("/usr/bin/apt-add-repository"):
        apt_get("python-software-properties")
        apt_get("software-properties-common")
    run("apt-add-repository --yes ppa:{0} || apt-add-repository ppa:{0}".format(repository_name))
    run("apt-get update")
