from fabric.api import task, cd , env, run
from infi.pyutils.lazy import cached_function
from .. import user_context, get_tempfile, get_and_put_file
import re

@cached_function
def _get_homedir_posix_style(host_string):
    return run("echo $HOME").strip()

def _get_path_variable_from_content(content):
    from itertools import chain
    regex = re.compile(r"^(?:export){0,1}\s*PATH=([$/\w\\. :~]+)$", re.MULTILINE)
    lines = regex.findall(content)
    keywords = set(chain(*[line.split(':') for line in lines]))
    keywords -= set(['$PATH'])
    return ':'.join(keywords)

def get_user_ssh_path_variable():
    with user_context(), cd(_get_homedir_posix_style(env.host_string)):
        with get_tempfile(".infinirc") as local_path:
            with open(local_path) as fd:
                content = fd.read()
        existing_path = _get_path_variable_from_content(content)
    return existing_path

def source_bashrc_from_bash_profile():
    update_file(".bash_profile", "if [ -f ~/.infinirc ]; then\nsource ~/.infinirc\nfi\n")

def update_file(filename, new_content, beginning=False):
    with user_context():
        with get_and_put_file(filename) as local_path:
            with open(local_path) as fd:
                data = fd.read()
            if new_content not in data:
                with open(local_path, 'wb') as fd:
                    new_data = [new_content, data] if beginning else [data, new_content]
                    fd.write("\n".join(new_data)+"\n")

def append_to_bashrc(line, beginning=False):
    source_bashrc_from_bash_profile()
    update_file(".infinirc", line, beginning)

def append_to_user_ssh_path_variable(dirname, beginning=False):
    with user_context(), cd(_get_homedir_posix_style(env.host_string)):
        existing_path = get_user_ssh_path_variable()
        if dirname in existing_path.split(":"):
            return
        if not existing_path:
            new_line = "export PATH={}:$PATH".format(dirname) if beginning else "export PATH=$PATH:{}".format(dirname)
            append_to_bashrc(new_line, beginning=True) # Must be in the beginning of bashrc, at least in windows
        else:
            regex = re.compile(r"^((?:export){0,1}\s*PATH=[$/\w\\. :~]+)$", re.MULTILINE)
            with get_and_put_file(".infinirc") as local_path:
                with open(local_path) as fd:
                    content = fd.read()
                    if beginning:
                        new_content = regex.sub(r'{}:\1'.format(dirname), content)
                    else:
                        new_content = regex.sub(r'\1:{}'.format(dirname), content)
                with open(local_path, 'wb') as fd:
                    fd.write(new_content)
