
from fabric.api import put, run, settings, task, puts, cd, env
from .. import user_context, get_tempfile, get_and_put_file, reconnect
from fabric.contrib.files import exists
import re

HKLM_ENVIRON_REG_KEY = r"HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment"
HKCU_ENVIRON_REG_KEY = r"HKCU\Environment"

REG = "/cygdrive/c/Windows/system32/reg.exe"

def get_homedir_windows_style():
    return r"C:\\Cygwin\\home\\Administrator"

def get_windows_profile():
    return "/cygdrive/c/Users/Administrator"

def get_systemroot():
    return "/cygdrive/c/Windows"

def is_administrator_account_exists():
    return exists(get_windows_profile())

def get_nt_version():
    output = run('cmd /c ver')
    return re.search("Version (\d\.\d)\.", output).group(1)

def is_windows_2003_or_xp():
    return get_nt_version() == "5.2"

def is_windows_7_or_2008_r2():
    return get_nt_version() == "6.1"

def is_windows_8_or_2012():
    return get_nt_version() == "6.2"

def is_windows_core_edition():
    return not exists("/cygdrive/c/Windows/system32/explorer.exe") and not exists("/cygdrive/c/WINDOWS/explorer.exe")

def get_windows_default_profile():
    path = "/cygdrive/c/Users/Default"
    return path if exists(path) else "{} User".format(path)

def get_program_files_windows_style():
    return r"C:\Program Files"

def get_program_files_posix_style():
    return "/cygdrive/c/Program\ Files"

def _extract_value_from_reg_query_output(out):
    result = re.match(r'.*REG.*SZ\s+(?P<path>[^\n]*)', out, re.DOTALL)
    if not result:
        return ''
    return result.groupdict().get('path', '')

def _escape_value(value):
    return value.replace("\\", "\\\\")

def escape_value(value):
    result = _escape_value(value)
    return result

@task
def get_systemwide_path_variable():
    with user_context():
        query = run("{} query '{}' /v Path".format(REG, HKLM_ENVIRON_REG_KEY))
        value = _extract_value_from_reg_query_output(query.stdout)
    puts("system path is {}".format(value))
    return value

@task
def set_systemwide_path_variable(path):
    with user_context():
        value = path
        stformat = "{} add '{}' /f /v Path /t REG_EXPAND_SZ /d '{}'"
        run(stformat.format(REG, HKLM_ENVIRON_REG_KEY, value), shell=False)

@task
def append_to_systemwide_path(dirname):
    with user_context():
        path = get_systemwide_path_variable()
        if dirname in path.split(';'):
            return
        path = ';'.join([path, dirname])
        set_systemwide_path_variable(path)

def _replace_newlines(content):
    from re import sub
    return sub("\r\n", "\n", content)

@task
def dos2unix(remote_path):
    from fabric.contrib.files import exists
    with user_context():
        if not exists(remote_path):
            return
        with get_and_put_file(remote_path) as local_path:
            with open(local_path) as fd:
                content = _replace_newlines(fd.read())
            with open(local_path, 'w') as fd:
                fd.write(content)
